@@ -9,9 +9,9 @@
 #' @examples
 #' library(dplyr)
 #' source(system.file("extdata", "walker_data.R", package = "nhdplusTools"))
-#' catchment_area <- prepare_nhdplus(walker_flowline, 0, 0,
-#'                              purge_non_dendritic = FALSE, warn = FALSE) %>%
-#'   left_join(select(walker_flowline, COMID, AreaSqKM), by = "COMID") %>%
+#' catchment_area <- select(walker_flowline, COMID, AreaSqKM) %>%
+#'   right_join(prepare_nhdplus(walker_flowline, 0, 0,
+#'                             purge_non_dendritic = FALSE, warn = FALSE), by = "COMID") %>%
 #'   select(ID = COMID, toID = toCOMID, area = AreaSqKM)
 #'
 #' new_da <- calculate_total_drainage_area(catchment_area)
@@ -39,9 +39,9 @@ calculate_total_drainage_area <- function(x) {
 #' @examples
 #' library(dplyr)
 #' source(system.file("extdata", "walker_data.R", package = "nhdplusTools"))
-#' catchment_length <- prepare_nhdplus(walker_flowline, 0, 0,
-#'                              purge_non_dendritic = FALSE, warn = FALSE) %>%
-#'   left_join(select(walker_flowline, COMID), by = "COMID") %>%
+#' catchment_length <- select(walker_flowline, COMID, AreaSqKM) %>%
+#'   right_join(prepare_nhdplus(walker_flowline, 0, 0,
+#'                             purge_non_dendritic = FALSE, warn = FALSE), by = "COMID") %>%
 #'   select(ID = COMID, toID = toCOMID, length = LENGTHKM)
 #'
 #' arb_sum <- calculate_arbolate_sum(catchment_length)
@@ -64,6 +64,8 @@ calculate_arbolate_sum <- function(x) {
 #'
 accumulate_downstream <- function(x, var) {
 
+  try(x <- st_drop_geometry(x), silent = TRUE)
+
   cat_order <- select(x, .data$ID)
 
   x[["toID"]][which(is.na(x[["toID"]]))] <- 0
