@@ -16,13 +16,12 @@ discover_nldi_sources <- function(tier = "prod") {
 #' @title Discover NLDI Navigation Options
 #' @description Discover available navigation options for a
 #' given feature source and id.
-#' @param nldi_feature list with names `featureSource` and `featureID` where
-#' `featureSource` is derived from the "source" column of  the response of
-#' discover_nldi_sources() and the `featureSource` is a known identifier
-#' from the specified `featureSource`.
+#' @param nldi_feature length 2 list list with optionsal names `featureSource`
+#' and `featureID` where `featureSource` is derived from the "source" column of
+#' the response of discover_nldi_sources() and the `featureSource` is a known identifier
+#' from the specified `featureSource`. e.g. list("nwissite", "USGS-08279500")
 #' @param tier character optional "prod" or "test"
-#' @return data.frame with three columns "source", "sourceName"
-#' and "features"
+#' @return data.frame with three columns "source", "sourceName" and "features"
 #' @export
 #' @examples
 #' \donttest{
@@ -31,9 +30,12 @@ discover_nldi_sources <- function(tier = "prod") {
 #' nldi_nwis <- list(featureSource = "nwissite", featureID = "USGS-08279500")
 #'
 #' discover_nldi_navigation(nldi_nwis)
+#'
+#' discover_nldi_navigation(list("nwissite", "USGS-08279500"))
 #' }
 discover_nldi_navigation <- function(nldi_feature, tier = "prod") {
-  check_nldi_feature(nldi_feature)
+  nldi_feature <- check_nldi_feature(nldi_feature)
+
   query <- paste(nldi_feature[["featureSource"]],
                  nldi_feature[["featureID"]],
                  "navigate", sep = "/")
@@ -88,9 +90,11 @@ discover_nldi_navigation <- function(nldi_feature, tier = "prod") {
 #' }
 #'
 navigate_nldi <- function(nldi_feature, mode = "upstreamMain",
-                          data_source = "comid", distance_km = NULL,
+                          data_source = "flowline", distance_km = NULL,
                           tier = "prod") {
 
+  nldi_feature <- check_nldi_feature(nldi_feature)
+
   nav_lookup <- list(upstreamMain = "UM",
                      upstreamTributaries = "UT",
                      downstreamMain = "DM",
@@ -104,6 +108,8 @@ navigate_nldi <- function(nldi_feature, mode = "upstreamMain",
     }
   }
 
+  if(data_source == "flowline") data_source <- ""
+
   query <- paste(nldi_feature[["featureSource"]],
                  nldi_feature[["featureID"]],
                  "navigate", mode, data_source,
@@ -152,6 +158,8 @@ navigate_nldi <- function(nldi_feature, mode = "upstreamMain",
 get_nldi_basin <- function(nldi_feature,
                           tier = "prod") {
 
+  nldi_feature <- check_nldi_feature(nldi_feature)
+
   query <- paste(nldi_feature[["featureSource"]],
                  nldi_feature[["featureID"]],
                  "basin",
@@ -162,12 +170,25 @@ get_nldi_basin <- function(nldi_feature,
 }
 
 
-
-#' @noRd
-get_nldi_feature <- function(f_source, f_id, tier = "prod") {
-  return(query_nldi(paste(f_source, f_id,
-                          sep = "/"),
-                    tier))
+#' @title Get NLDI Feature
+#' @description Get a single feature from the NLDI
+#' @param nldi_feature list with names `featureSource` and `featureID` where
+#' `featureSource` is derived from the "source" column of  the response of
+#' discover_nldi_sources() and the `featureSource` is a known identifier
+#' from the specified `featureSource`.
+#' @param tier character optional "prod" or "test"
+#' @return sf feature collection with one feature
+#' @examples
+#' \donttest{
+#' get_nldi_feature(list("featureSource" = "nwissite", featureID = "USGS-05428500"))
+#' }
+#' @export
+get_nldi_feature <- function(nldi_feature, tier = "prod") {
+  nldi_feature <- check_nldi_feature(nldi_feature)
+  return(sf::read_sf(query_nldi(paste(nldi_feature[["featureSource"]],
+                                      nldi_feature[["featureID"]],
+                                      sep = "/"),
+                                tier, parse_json = FALSE)))
 }
 
 #' @importFrom httr GET
@@ -179,7 +200,7 @@ query_nldi <- function(query, tier = "prod", parse_json = TRUE) {
   url <- paste(nldi_base_url, query,
                sep = "/")
 
-  req_data <- rawToChar(httr::RETRY("GET", url, times = 10, pause_cap = 240)$content)
+  req_data <- rawToChar(httr::RETRY("GET", url, times = 3, pause_cap = 60)$content)
 
   if (nchar(req_data) == 0) {
     NULL
@@ -200,9 +221,9 @@ query_nldi <- function(query, tier = "prod", parse_json = TRUE) {
 #' @noRd
 get_nldi_url <- function(tier = "prod") {
   if (tier == "prod") {
-    "https://cida.usgs.gov/nldi"
+    "https://labs.waterdata.usgs.gov/api/nldi/linked-data"
   } else if (tier == "test") {
-    "https://cida-test.er.usgs.gov/nldi"
+    "https://labs-beta.waterdata.usgs.gov/api/nldi/linked-data"
   } else {
     stop("only prod or test allowed.")
   }
@@ -211,12 +232,14 @@ get_nldi_url <- function(tier = "prod") {
 #' @noRd
 check_nldi_feature <- function(nldi_feature) {
   expect_names <- c("featureSource", "featureID")
-  if (!all(expect_names %in%
-           names(nldi_feature))) {
-    stop(paste0("Missing some required input for NLDI. ",
-                "Expected: ",
-                paste(expect_names[which(!(expect_names %in%
-                                             names(nldi_feature)))],
-                      collapse = ", ")))
+  if (!all(expect_names %in% names(nldi_feature))) {
+    if(length(nldi_feature) != 2 | !all(sapply(nldi_feature, is.character)))
+      stop(paste0("Missing some required input for NLDI. ",
+                  "Expected length 2 character vector or list with optional names: ",
+                  paste(expect_names[which(!(expect_names %in%
+                                               names(nldi_feature)))],
+                        collapse = ", ")))
   }
+  names(nldi_feature) <- expect_names
+  return(as.list(nldi_feature[expect_names]))
 }
