@@ -118,12 +118,24 @@ assign("get_flowline_index_attributes",
        c("COMID", "REACHCODE", "ToMeas", "FromMeas"),
        envir = nhdplusTools_env)
 
-assign("calculate_levelpaths_attributes",
+assign("get_levelpaths_attributes",
        c("ID", "toID", "nameID", "weight"),
        envir = nhdplusTools_env)
 
+assign("get_streamorder_attributes",
+       c("ID", "toID"),
+       envir = nhdplusTools_env)
+
+assign("get_pfaf_attributes",
+       c("ID", "toID", "totda", "outletID", "topo_sort", "levelpath"),
+       envir = nhdplusTools_env)
+
+assign("make_standalone_attributes",
+       c("COMID", "ToNode", "FromNode", "TerminalFl", "Hydroseq", "TerminalPa",
+         "LevelPathI", "FTYPE"), envir = nhdplusTools_env)
+
 check_names <- function(x, function_name) {
-  x <- rename_nhdplus(x)
+  x <- align_nhdplus_names(x)
   names_x <- names(x)
   expect_names <- get(paste0(function_name, "_attributes"),
                       envir = nhdplusTools_env)
@@ -137,25 +149,6 @@ check_names <- function(x, function_name) {
   return(x)
 }
 
-#' @noRd
-rename_nhdplus <- function(x) {
-  attribute_names <- get("nhdplus_attributes", envir = nhdplusTools_env)
-
-  old_names <- names(x)
-  new_names <- old_names
-
-  matched <- match(names(x), names(attribute_names))
-  replacement_names <- as.character(attribute_names[matched[which(!is.na(matched))]])
-
-  new_names[which(old_names %in% names(attribute_names))] <- replacement_names
-
-  names(x) <- new_names
-
-  if("GridCode" %in% names(x)) names(x)[which(names(x) == "COMID")] <- "FEATUREID"
-
-  return(x)
-}
-
 default_nhdplus_path <- "../NHDPlusV21_National_Seamless.gdb"
 
 assign("default_nhdplus_path", default_nhdplus_path, envir = nhdplusTools_env)
@@ -223,24 +216,34 @@ nhdplus_path <- function(path = NULL, warn = FALSE) {
 #'
 #' names(new_hope_flowline)
 #'
-align_nhdplus_names = function(x){
+align_nhdplus_names <- function(x){
 
-  good_names <- unique(unlist(do.call(rbind, nhdplus_attributes))[,1])
+  attribute_names <- get("nhdplus_attributes", envir = nhdplusTools_env)
 
-  old_names <- names(x)
-  new_names <- old_names
+  # get into correct case
+  good_names <- unique(unlist(do.call(rbind, attribute_names))[,1])
+
+  new_names <- old_names <- names(x)
 
   matched <- match(toupper(names(x)), toupper(good_names))
-
   replacement_names <- as.character(good_names[matched[which(!is.na(matched))]])
 
   new_names[which(toupper(old_names) %in% toupper(good_names))] <- replacement_names
   names(x) <- new_names
+
+  # rename to match package
+  new_names <- old_names <- names(x)
+
+  matched <- match(names(x), names(attribute_names))
+  replacement_names <- as.character(attribute_names[matched[which(!is.na(matched))]])
+
+  new_names[which(old_names %in% names(attribute_names))] <- replacement_names
+
+  names(x) <- new_names
+
+  if("GridCode" %in% names(x) & !"FeatureID" %in% names(x) & !"FEATUREID" %in% names(x))
+    names(x)[which(names(x) == "COMID")] <- "FEATUREID"
+
   return(x)
 
 }
-
-
-
-
-
